.. role:: raw-html(raw)
   :format: html

.. _GitHub: https://github.com/liquidweb/spektrum


Spektrum
========

Spektrum is a Python testing framework inspired from RSpec and Jasmine.
The library was created out of a desire to have a relatively flexible Python
testing framework that adopted a more code-centric approach to BDD.

Spektrum is open-source and is available on `GitHub`_. We love contributions!

Getting Started
~~~~~~~~~~~~~~~~

Continuous Integration
~~~~~~~~~~~~~~~~~~~~~~~

Release Notes
~~~~~~~~~~~~~~

- `Release notes`_ are available in the documentation
